@@ -1,7 +1,3 @@
-from .loci_file import open_loci_file
-
-# tools
-
 from .tools.extend import extend
 from .tools.filter import filter
 from .tools.view import view
